==> jquery.text-select-1.0.0.tgz: package/README.md <==
# Select Text

A jQuery plugin to select, unselect and, if supported by the browser, copy text


## Installation

Install with NPM:

```npm install --save jquery.select-text```


## Usage

- Include jQuery
- Include jquery.select-text.js:

```html
<script src="/path/to/jquery.js"></script>
<script src="/path/to/jquery.select-text.js"></script>
```

- Alternatively you can use webpack / browserify:
```require('jquery.select-text');
```


```<script>
  $(document).ready(function(){
    $("#selectMe").selectText(); // Hightlight / select the text
    $("#selectMe").selectText(false); // Clear the selection

    $("#copyMe").selectText(); // Copy text to clipboard


  });
</script>
```

## Methods

- `selectText(select)`: Selects the text; if `false` is passed unselects the text
- `copyText()`: Copies the text to clipboard, if supported by the browser (see notes below)

## Events

- `selecttext.selected`: When text is selected
- `selecttext.unselected`: When the selection is cleared
- `selecttext.copied`: When text is successfully copied to the clipboard

## Notes

This plugin is a jQuery wrapper for code presented by Tim Down (https://stackoverflow.com/users/96100/tim-down), Gert Grenader (https://stackoverflow.com/users/339850/gert-grenander) and Dean Taylor (https://stackoverflow.com/users/406712/dean-taylor).

The plugin depends on `document.execCommand('copy')`, which according to MDN has the following support:

Chrome: (Yes)
Edge: (Yes)
Firefox: 41
IE: 9
Opera: 29
Safari: 10

For utility, the plugin attaches a boolean property `canCopyText` to the global jQuery object.  This will be true or false.  You can use this to check for browser support and show / hide copy buttons as appropriate.  If the `copyText` command is run without browser support no action will be taken and a warning logged to the console.

==> jquery.text-select-1.0.1.tgz: package/README.md <==
# Select Text

A jQuery plugin to select, unselect and, if supported by the browser, copy text


## Installation

Install with NPM:

```npm install --save jquery.select-text```


## Usage

- Include jQuery
- Include jquery.select-text.js:

```
<script src="/path/to/jquery.js"></script>
<script src="/path/to/jquery.select-text.js"></script>
```

- Alternatively you can use webpack / browserify:
```
require('jquery.select-text');
```


```
<script>
  $(document).ready(function(){
    $("#selectMe").selectText(); // Hightlight / select the text
    $("#selectMe").selectText(false); // Clear the selection

    $("#copyMe").selectText(); // Copy text to clipboard


  });
</script>
```

## Methods

- `selectText(select)`: Selects the text; if `false` is passed unselects the text
- `copyText()`: Copies the text to clipboard, if supported by the browser (see notes below)

## Events

- `selecttext.selected`: When text is selected
- `selecttext.unselected`: When the selection is cleared
- `selecttext.copied`: When text is successfully copied to the clipboard

## Notes

This plugin is a jQuery wrapper for code presented by [https://stackoverflow.com/users/96100/tim-down](Tim Down), [https://stackoverflow.com/users/339850/gert-grenander](Gert Grenader) and [https://stackoverflow.com/users/406712/dean-taylor](Dean Taylor).

The plugin depends on `document.execCommand('copy')`, which according to MDN has the following support:

Chrome | (Yes)
Edge | (Yes)
Firefox | 41
IE | 9
Opera | 29
Safari | 10

For utility, the plugin attaches a boolean property `canCopyText` to the global jQuery object.  This will be true or false.  You can use this to check for browser support and show / hide copy buttons as appropriate.  If the `copyText` command is run without browser support no action will be taken and a warning logged to the console.
